==> xld-codepipeline-plugin-1.0.0-sources.jar: com/xebialabs/deployit/plugin/codepipeline/actions/ImportAction.java <==
package com.xebialabs.deployit.plugin.codepipeline.actions;

import com.amazonaws.service.codepipeline.model.Job;
import com.xebialabs.deployit.plugin.api.udm.ConfigurationItem;
import com.xebialabs.deployit.plugin.codepipeline.exceptions.CodePipelinePluginExecutionException;
import com.xebialabs.deployit.plugin.codepipeline.helpers.ConfigurationItemUtils;
import com.xebialabs.deployit.plugin.codepipeline.helpers.DarHelper;
import com.xebialabs.deployit.plugin.codepipeline.helpers.DarInfo;
import com.xebialabs.deployit.plugin.codepipeline.services.CodePipelineJobService;
import com.xebialabs.deployit.plugin.codepipeline.services.XLDeployService;
import org.slf4j.Logger;
import org.slf4j.LoggerFactory;

import java.io.IOException;
import java.nio.file.Files;
import java.nio.file.Path;

public class ImportAction extends Action<ConfigurationItem> {

    private static final Logger LOGGER = LoggerFactory.getLogger(ImportAction.class);

    private final CodePipelineJobService jobService;
    private final XLDeployService xlDeployService;
    private final Job job;
    private final String deploymentPackageName;
    private final String deploymentPackageVersion;

    public ImportAction(final XLDeployService xlDeployService,
                        final CodePipelineJobService jobService, final Job job,
                        String deploymentPackageName, String deploymentPackageVersion) {
        this.xlDeployService = xlDeployService;
        this.jobService = jobService;
        this.job = job;
        this.deploymentPackageName = deploymentPackageName;
        this.deploymentPackageVersion = deploymentPackageVersion;
    }

    @Override
    public ConfigurationItem execute() {
        return validateAndImportArtifact(job, deploymentPackageName, deploymentPackageVersion);
    }

    @Override
    public String actionName() {
        return "Import package";
    }

    private ConfigurationItem validateAndImportArtifact(Job job, String deploymentPackageName,
                                                        String deploymentPackageVersion) {
        Path path = jobService.getPackagePath(job);
        if (path == null)
            throw new CodePipelinePluginExecutionException("Unable to get downloaded file path");
        try {
            DarInfo info = DarHelper.getDarInfo(path);
            validateConfigurationItem(info, deploymentPackageName, deploymentPackageVersion);
            ConfigurationItem item = xlDeployService.importPackage(path);
            return item;
        } finally {
            cleanupFile(path);
        }
    }

    private void cleanupFile(Path path) {
        try {
            Files.delete(path);
        } catch (IOException ex) {
            LOGGER.error("Unable to delete temp file " + path.getFileName(), ex);
        }
    }

    private void validateConfigurationItem(DarInfo info, String deploymentPackageName,
                                           String deploymentPackageVersion) {
        if (info == null) {
            return;
        }
        validateVersion(info.getVersion(), deploymentPackageVersion);
        validateName(info.getName(), ConfigurationItemUtils.getNameFromId(deploymentPackageName));
    }

    private void validateVersion(String ciPackageVersion, String deploymentPackageVersion) {
        deploymentPackageVersion = deploymentPackageVersion == null ? "" : deploymentPackageVersion;
        if (!deploymentPackageVersion.isEmpty() && !deploymentPackageVersion.equals(ciPackageVersion))
            throw new CodePipelinePluginExecutionException(
                    String.format("Deployment Package version '%s' is different from packaged version '%s' inside S3 bucket", deploymentPackageVersion, ciPackageVersion));

    }

    private void validateName(String ciPackageName, String deploymentPackageName) {
        if (!ciPackageName.equals(deploymentPackageName))
            throw new CodePipelinePluginExecutionException(
                    String.format("Deployment Package name '%s' is different from packaged name '%s' inside S3 bucket", deploymentPackageName, ciPackageName));
    }

}

==> xld-codepipeline-plugin-1.0.1-sources.jar: com/xebialabs/deployit/plugin/codepipeline/actions/ImportAction.java <==
package com.xebialabs.deployit.plugin.codepipeline.actions;

import com.amazonaws.services.codepipeline.model.Job;
import com.xebialabs.deployit.plugin.api.udm.ConfigurationItem;
import com.xebialabs.deployit.plugin.codepipeline.exceptions.CodePipelinePluginExecutionException;
import com.xebialabs.deployit.plugin.codepipeline.helpers.ConfigurationItemUtils;
import com.xebialabs.deployit.plugin.codepipeline.helpers.DarHelper;
import com.xebialabs.deployit.plugin.codepipeline.helpers.DarInfo;
import com.xebialabs.deployit.plugin.codepipeline.services.CodePipelineJobService;
import com.xebialabs.deployit.plugin.codepipeline.services.XLDeployService;
import org.slf4j.Logger;
import org.slf4j.LoggerFactory;

import java.io.IOException;
import java.nio.file.Files;
import java.nio.file.Path;

public class ImportAction extends Action<ConfigurationItem> {

    private static final Logger LOGGER = LoggerFactory.getLogger(ImportAction.class);

    private final CodePipelineJobService jobService;
    private final XLDeployService xlDeployService;
    private final Job job;
    private final String deploymentPackageName;
    private final String deploymentPackageVersion;

    public ImportAction(final XLDeployService xlDeployService,
                        final CodePipelineJobService jobService, final Job job,
                        String deploymentPackageName, String deploymentPackageVersion) {
        this.xlDeployService = xlDeployService;
        this.jobService = jobService;
        this.job = job;
        this.deploymentPackageName = deploymentPackageName;
        this.deploymentPackageVersion = deploymentPackageVersion;
    }

    @Override
    public ConfigurationItem execute() {
        return validateAndImportArtifact(job, deploymentPackageName, deploymentPackageVersion);
    }

    @Override
    public String actionName() {
        return "Import package";
    }

    private ConfigurationItem validateAndImportArtifact(Job job, String deploymentPackageName,
                                                        String deploymentPackageVersion) {
        Path path = jobService.getPackagePath(job);
        if (path == null)
            throw new CodePipelinePluginExecutionException("Unable to get downloaded file path");
        try {
            DarInfo info = DarHelper.getDarInfo(path);
            validateConfigurationItem(info, deploymentPackageName, deploymentPackageVersion);
            ConfigurationItem item = xlDeployService.importPackage(path);
            return item;
        } finally {
            cleanupFile(path);
        }
    }

    private void cleanupFile(Path path) {
        try {
            Files.delete(path);
        } catch (IOException ex) {
            LOGGER.error("Unable to delete temp file " + path.getFileName(), ex);
        }
    }

    private void validateConfigurationItem(DarInfo info, String deploymentPackageName,
                                           String deploymentPackageVersion) {
        if (info == null) {
            return;
        }
        validateVersion(info.getVersion(), deploymentPackageVersion);
        validateName(info.getName(), ConfigurationItemUtils.getNameFromId(deploymentPackageName));
    }

    private void validateVersion(String ciPackageVersion, String deploymentPackageVersion) {
        deploymentPackageVersion = deploymentPackageVersion == null ? "" : deploymentPackageVersion;
        if (!deploymentPackageVersion.isEmpty() && !deploymentPackageVersion.equals(ciPackageVersion))
            throw new CodePipelinePluginExecutionException(
                    String.format("Deployment Package version '%s' is different from packaged version '%s' inside S3 bucket", deploymentPackageVersion, ciPackageVersion));

    }

    private void validateName(String ciPackageName, String deploymentPackageName) {
        if (!ciPackageName.equals(deploymentPackageName))
            throw new CodePipelinePluginExecutionException(
                    String.format("Deployment Package name '%s' is different from packaged name '%s' inside S3 bucket", deploymentPackageName, ciPackageName));
    }

}
